@@ -20,7 +20,7 @@ from peewee import JOIN
 from porerefiner import models
 from porerefiner.models import Run, Qa, File, Job, SampleSheet, Sample, Tag, TagJunction
 from porerefiner.cli_utils import relativize_path as r, absolutize_path as a, json_formatter
-from porerefiner.jobs import poll_jobs, REGISTRY, JOBS
+from porerefiner.jobs import poll_jobs, CLASS_REGISTRY, JOBS
 from os.path import split, getmtime
 from os import remove
 from pathlib import Path
